local StoneGateV6 = ...

-- Apply building asset processor
StoneGateV6:registerAssetProcessor("models/woodenFloors/baseOverHanging.fbx", {
	DataType = "BUILDING_ASSET_PROCESSOR"
})

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	StoneGateV6:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = {
                    DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                    CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                },
	        Cost = {
		    UpkeepCost = {
			{ Resource = "GOLD", Quantity = 1 }
		    },
		    RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		    }
	        },
	        EstateSplendor = {
		    { Estate = "KINGDOM", Quantity = 0.1 }
	    }
	})
end

function registerRootPart(_nameFbxFile, _nameModel, _nameFbx, _nameAsset, _stoneCost)

    -- Register Keep prefab nodes
    StoneGateV6:registerAssetId("models/woodenFloors/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameModel .. "/step_0_".. _nameFbx .. "_RootPart", StoneGateSetPrefix .. "_" ..  _nameAsset .. "_ROOT_PREFAB")
    StoneGateV6:registerAssetId("models/woodenFloors/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameModel .. "/step_1_".. _nameFbx .. "_Tiling1PPart", StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TILING1P_PREFAB")
    StoneGateV6:registerAssetId("models/woodenFloors/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameModel .. "/step_2_".. _nameFbx .. "_Tiling2PPart", StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TILING2P_PREFAB")
    StoneGateV6:registerAssetId("models/woodenFloors/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameModel .. "/step_3_".. _nameFbx .. "_TopPart", StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TOP_PREFAB")
    --------------------------------------------------------------------------

    registerDefaultBuildingPart(StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TOP")
    registerDefaultBuildingPart(StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TILING1P")
    registerDefaultBuildingPart(StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TILING2P")

    -- Register the stone gate set keep root wooden floor whith overhanging part
    StoneGateV6:register({
	DataType = "BUILDING_PART",
	Id = StoneGateSetPrefix .. "_" ..  _nameAsset .. "_ROOTP_PART",
	Name = StoneGateSetPrefix .. "_" ..  _nameAsset .. "_ROOTP_NAME",
	Description = StoneGateSetPrefix .. "_" ..  _nameAsset .. "_ROOTP_DESC",
	Category = "CORE",
        BuildingZone = _OverHangingBuildingZone,
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = StoneGateSetPrefix .. "_" ..  _nameAsset .. "_ROOT_PREFAB",
		EndPart = StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TOP_PART",
		FillerList = {
			StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TILING2P_PART"
                },
		BasementFillerList = {
			StoneGateSetPrefix .. "_" ..  _nameAsset .. "_TILING1P_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true,
                IsPreviewGroundVisible = false
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "STONE", Quantity = 2 }
		}
	},
	EstateSplendor = {
		{ Estate = "KINGDOM", Quantity = 1 }
	},
        VillagerCapacity = 12,
	AssetBuildingFunction = "BUILDING_FUNCTION_ASSIGNABLE_LORD_MANOR"
    })


    --------------------------------------------------------------------------

    -- Register grass clearing components

    StoneGateV6:registerPrefabComponent("models/woodenFloors/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameModel .. "/step_0_".. _nameFbx .. "_RootPart", {
	DataType = "COMP_DIRT_RECTANGLE",
	Size = { 8, 8 }
    })

    -- Override building part components properties (generated by the building asset processor) to add building zones
    StoneGateV6:registerPrefabComponent("models/woodenFloors/" .. _nameFbxFile .. ".fbx/Prefab/" .. _nameModel .. "/step_0_".. _nameFbx .. "_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 8, 8 }
    })
end

registerRootPart("baseOverHanging", "keep", "KeepH", "KEEPH", 2)
registerRootPart("baseOverHanging", "keep", "KeepI", "KEEPI", 2)
registerRootPart("baseOverHanging", "keep", "KeepJ", "KEEPJ", 2)
registerRootPart("baseOverHanging", "keep", "KeepK", "KEEPK", 2)
registerRootPart("baseOverHanging", "keep", "KeepL", "KEEPL", 2)
